@@ -3,7 +3,7 @@ var config = {
     //host: "https://localhost:8080",
     //appId: "d8fcffc5-d1ab-40f1-ac63-d2643d7b9464",
    // appKey: "5fc02522e60958787b8298067513c5f4b44ca78a",
-    database: {
+   /* database: {
       db:'test',
       host: '192.168.10.33',
       port: 28015,
@@ -14,7 +14,7 @@ var config = {
     ws:{
        url: 'ws://192.168.10.33:8000/ws',
        realm: 'realm1'
-    },
+    },*/
 
    /* oauth: {
       facebook: {
